<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>變更紀錄</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>關閉（&amp;C）</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>主窗口</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>軟件（xrandr）亮度</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>硬件背光</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-調整</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>顯示</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>＆退出</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="78"/>
        <location filename="../defaultlook.cpp" line="629"/>
        <location filename="../defaultlook.cpp" line="648"/>
        <location filename="../defaultlook.cpp" line="657"/>
        <location filename="../defaultlook.cpp" line="699"/>
        <location filename="../defaultlook.cpp" line="709"/>
        <location filename="../defaultlook.cpp" line="737"/>
        <location filename="../defaultlook.cpp" line="740"/>
        <source>MX Tweak</source>
        <translation>MX 調校</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="32"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;自訂邊條&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="46"/>
        <location filename="../defaultlook.ui" line="156"/>
        <source>Panel</source>
        <translation>邊條</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="66"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;設定視窗行為與捷徑&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="80"/>
        <source>Window Manager</source>
        <translation>視窗管理程式</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="100"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;自訂桌面外觀&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="114"/>
        <source>Appearance</source>
        <translation>外觀</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="129"/>
        <source>Xfce Settings</source>
        <translation>設定 Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="320"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;影響到所有邊條&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="227"/>
        <location filename="../defaultlook.ui" line="1452"/>
        <source>Affects 1st panel</source>
        <translation>影響到第一條邊條</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="280"/>
        <location filename="../defaultlook.ui" line="1475"/>
        <source>Left</source>
        <translation>左側</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="285"/>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>Right</source>
        <translation>右側</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="204"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;視窗按鈕&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="254"/>
        <location filename="../defaultlook.ui" line="1470"/>
        <source>Bottom</source>
        <translation>下側</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="259"/>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>Top</source>
        <translation>上側</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="164"/>
        <location filename="../defaultlook.ui" line="303"/>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="310"/>
        <source>Display panel horizontally</source>
        <translation>邊條水平顯示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="171"/>
        <source>Display panel vertically</source>
        <translation>邊條垂直顯示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="211"/>
        <source>Restore default panel</source>
        <translation>回復成預設邊條</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="181"/>
        <source>Backup current panel configuration</source>
        <translation>備份目前使用的邊條設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Restore backup panel configuration</source>
        <translation>由備份檔回復邊條設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="353"/>
        <location filename="../defaultlook.ui" line="405"/>
        <location filename="../defaultlook.ui" line="561"/>
        <location filename="../defaultlook.ui" line="886"/>
        <location filename="../defaultlook.ui" line="893"/>
        <location filename="../defaultlook.ui" line="900"/>
        <location filename="../defaultlook.ui" line="1016"/>
        <location filename="../defaultlook.ui" line="1417"/>
        <location filename="../defaultlook.ui" line="1610"/>
        <location filename="../defaultlook.ui" line="1766"/>
        <source>Apply</source>
        <translation>使用</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="384"/>
        <source>Theme</source>
        <translation>佈景</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="392"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="428"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>使用暗色系佈景時，校正 HexChat 的輸入區</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="435"/>
        <source>Preview</source>
        <translation>預覽</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="442"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>使用暗色系佈景時，校正某些網站的欄位</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="445"/>
        <source>Firefox dark theme tweak</source>
        <translation>Firefox 暗色系佈景調校</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="452"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="459"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="466"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="486"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>將當前設置另存為主題集</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="497"/>
        <source>Remove User Theme Set</source>
        <translation>刪除用戶主題集</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="514"/>
        <source>Theme Options</source>
        <translation>佈景選項 </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="537"/>
        <source>Undo</source>
        <translation>復原</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="547"/>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Compositor</source>
        <translation>桌面排版程式</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="581"/>
        <source>Transparency and shadow options</source>
        <translation>視窗透明化與投射陰影的選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="595"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>利用文字編緝程式直接修改 compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="598"/>
        <source>Edit compton.conf</source>
        <translation>編緝 compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="648"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;更改VBlank模式可能有助於減輕某些屏幕撕裂問題。有關更多信息，請參見「幫助」。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="651"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="659"/>
        <source>auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="664"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="669"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="674"/>
        <source>off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="695"/>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="700"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm（Xfce）桌面排版程式</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="705"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="713"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;設定 Xfce 的桌面排版程式&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="716"/>
        <source>Xfwm Settings</source>
        <translation>設定 Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="727"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>啟動 compton-conf 設定工具</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="730"/>
        <source>Compton settings</source>
        <translation>設定 Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="744"/>
        <source>Display</source>
        <translation>顯示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="752"/>
        <source>Hardware Backlight</source>
        <translation>硬件背光</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="759"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;顯示調整&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="786"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>為xrandr調整選擇顯示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="796"/>
        <source>Resolution</source>
        <translation>解析度</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="803"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;按顯示保存&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="806"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="813"/>
        <source>Software (xrandr) Brightness</source>
        <translation>軟件（xrandr）亮度</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="820"/>
        <location filename="../defaultlook.ui" line="917"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="827"/>
        <source>GTK scaling</source>
        <translation>GTK 縮放</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>xrandr Scaling</source>
        <translation>xrandr 縮放比例</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="943"/>
        <source>Config Options</source>
        <translation>設定選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1047"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>將 Thunar 當中右鍵的自訂動作回復成系統預設的動作</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="996"/>
        <source>Enable single-click on desktop</source>
        <translation>在桌面上啟用游標單擊</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="951"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>在 Thunar 檔案管理員中啟用游標單擊</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1054"/>
        <source>Enable Desktop Zoom </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="975"/>
        <location filename="../defaultlook.ui" line="1570"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>在邊條中顯示來自所有工作區的視窗</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1003"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>在桌面上，不把過長檔名簡化顯示</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="989"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>在登出選單中啟用休眠選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="968"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>註：若欲休眠，swap 必須大於 RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1027"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="958"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="982"/>
        <source>Thunar windows always open in split view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1061"/>
        <source>Thunar split view opens horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1071"/>
        <source>Fluxbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1079"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1113"/>
        <location filename="../defaultlook.ui" line="1149"/>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1118"/>
        <location filename="../defaultlook.ui" line="1154"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1123"/>
        <source>On Hover</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1141"/>
        <location filename="../defaultlook.ui" line="1162"/>
        <source>Autohide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1169"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1459"/>
        <source>Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <source>Reset DefaultDock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <source>Toggle desktop icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <source>Reset Fluxbox Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1345"/>
        <location filename="../defaultlook.ui" line="1577"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1352"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1359"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1366"/>
        <source>Toggle icon captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1373"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1380"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1387"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1390"/>
        <source>Upgrade existing menu entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1410"/>
        <source>Show Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1438"/>
        <source>Plasma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1493"/>
        <source>Systray Icon Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1504"/>
        <source>Default</source>
        <translation>預設</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1509"/>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1514"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1519"/>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1524"/>
        <source>Larger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1529"/>
        <source>Largest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1556"/>
        <source>Workspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1563"/>
        <source>Enable single-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1584"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1624"/>
        <source>Other</source>
        <translation>其它</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1691"/>
        <source>Password for administrative tasks:</source>
        <translation>管理任務的密碼：</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1639"/>
        <source>Use tearfree radeon driver option</source>
        <translation>使用無淚radeon驅動程序選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1653"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          注意：現有的/etc/X11/xorg.conf.d/20-radeon.conf將備份到主文件夾</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1698"/>
        <source>&amp;User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1705"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>使用英特爾驅動代替默認的「模式設置」驅動（需要重啟）。</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1753"/>
        <source>Enable kernel sandbox</source>
        <translation>啟用內核沙箱</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1677"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>註：現所採用的 /etc/X11/xorg.conf.d/20-intel.conf 會備份到家目錄當中</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1719"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>將 Lightdm（登入畫面）回復成系統預設的佈景</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1684"/>
        <source>Use libinput driver for touchpad instead of synaptics touchpad driver (requires restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1646"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>         注意：現有的/etc/X11/xorg.conf.d/20-amd.conf將備份到主文件夾
</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1632"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>容許並非 root 的使用者掛載內接式硬碟</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1712"/>
        <source>Use tearfree amdgpu option</source>
        <translation>使用無淚amdgpu選項</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1726"/>
        <source>Root</source>
        <translation>最高用戶</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1660"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1424"/>
        <source>Manage Tint2 Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1667"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1670"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1777"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1846"/>
        <source>About</source>
        <translation>關於</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1857"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1874"/>
        <source>Quit application</source>
        <translation>退出程式</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1877"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1884"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--display開關僅對Xfce有效</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="628"/>
        <source>About MX Tweak</source>
        <translation>關於 MX 調校</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="630"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="631"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>本程式可快速更換與調校預設介面佈景</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="633"/>
        <source>Copyright (c) MX Linux</source>
        <translation>版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="634"/>
        <source>%1 License</source>
        <translation>%1 許可</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="648"/>
        <source>%1 Help</source>
        <translation>%1 幫助</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="658"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>完成！可能需要重新啟動 Firefox，這些變動才會生效。</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="700"/>
        <source>Plese remove special characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="700"/>
        <source>from file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="710"/>
        <source>File name already exists.  Choose another name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="738"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="741"/>
        <source>Archive does not contain a panel config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="861"/>
        <source>Panel settings</source>
        <translation>邊條設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="862"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>您當前的面板設置已備份到主文件夾（~/ .restore/）中名為.restore的隱藏文件夾中。</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1563"/>
        <source>settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1903"/>
        <source>Choose a theme set</source>
        <translation>選擇一套佈景組合</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>刪除用戶主題集</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>新主題集</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>輸入新主題集的名稱</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>視窗按鈕</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;外觀&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>顯示按鈕標籤</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>顯示扁平按鈕</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>顯示控制把</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>排序：</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>時間戳記</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>群組標題與時間戳記</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>視窗標題</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>群組標題與視窗標題</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>無，允許拖放</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;行為&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>視窗群組：</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>永不</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>總是</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>中鍵點擊動作：</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>不動作</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>關閉視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>最小化視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>還原最小化視窗至目前工作區</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>當滑鼠停在按鈕上時繪製視窗框架</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>用滑鼠滾輪切換視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;過濾方式&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>顯示所有工作區視域內的視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>只顯示最小化的視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>顯示所有螢幕的視窗</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>對話視窗</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>彈出式視窗</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>移動視窗時</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;不透明度設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>視窗裝飾</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>在塢區視窗下顯示陰影</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>在彈出式視窗下顯示陰影</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>調整視窗大小時</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>在一般視窗下顯示陰影</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;功能設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>循環切換時，顯示視窗預覽而非圖示</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>以直接覆蓋視窗的方式顯示全螢幕</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>非活動中視窗</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>將圖形同步到垂直空白</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>設定 Xfwm 桌面排版程式</translation>
    </message>
</context>
</TS>
